import{C as r,E as t,K as i,a as c,M as f,c as l,P as y,R as g,S as u,b,T as k,U as p,e as w,l as D}from"./toggleHighContrast.85043cfd.js";import"./outputWidgets.02d7c6ab.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="28c7c18f-47d7-4d1d-89d8-1023d8397c7a",e._sentryDebugIdIdentifier="sentry-dbid-28c7c18f-47d7-4d1d-89d8-1023d8397c7a")}catch{}})();export{r as CancellationTokenSource,t as Emitter,i as KeyCode,c as KeyMod,f as MarkerSeverity,l as MarkerTag,y as Position,g as Range,u as Selection,b as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.9a49a0c6.js.map
