import{S as p}from"./Sidebar.788e3dab.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.281bf392.js";import{E as d,F as l,G as u}from"./icons.d148c279.js";import{d as b,eB as f,H as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.02d7c6ab.js";import{a as w}from"./asyncComputed.6ba28f12.js";import"./router.1ffd6f3d.js";import"./index.91e5c23a.js";import{O as z}from"./organization.6d3db9f6.js";import{B as h}from"./BaseLayout.898ec023.js";import"./index.48b86b74.js";import"./logo.084e5d7c.js";import"./Text.4830f6bb.js";import"./Base.a464e3b8.js";import"./Typography.9f15a3fb.js";import"./index.63b077a7.js";import"./FormItem.08e761e4.js";import"./hasIn.16bcfc34.js";import"./index.cf4c23b9.js";import"./record.4bf6e864.js";import"./pubsub.ee609699.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="19c39a93-9313-4b2f-9d34-dbaecef0e716",e._sentryDebugIdIdentifier="sentry-dbid-19c39a93-9313-4b2f-9d34-dbaecef0e716")}catch{}})();const J=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:t}=w(()=>z.get(n)),i=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:a(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(p,{class:"sidebar",sections:s})]),content:a(()=>[r(m)]),_:1})}}});export{J as default};
//# sourceMappingURL=Organization.970f085b.js.map
