import{g as h}from"./api.2e2d3245.js";import{a as k}from"./asyncComputed.6ba28f12.js";import{d as x,eA as w,H as C,b as t,ev as m,u as e,c as s,ex as _,e as I,w as n,ew as D,bv as B,ar as f,a$ as N,eC as T,f as p,eD as H,I as V,v as z}from"./outputWidgets.02d7c6ab.js";import{e as A}from"./icons.d148c279.js";import{P as F}from"./PlayerNavbar.01a0e5b9.js";import"./index.749b48cd.js";import"./index.72674e5a.js";import{A as y}from"./index.3efceebc.js";import{T as g}from"./Typography.9f15a3fb.js";import{C as S}from"./Card.c07f4cec.js";import"./runnerData.00697345.js";import"./url.425ecd45.js";import"./Base.a464e3b8.js";import"./Link.f80ea6a6.js";import"./Paragraph.fbd3cedb.js";import"./Text.4830f6bb.js";import"./Title.5b74a8b2.js";import"./TabPane.ae8f30bc.js";import"./hasIn.16bcfc34.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[i]="c760babc-8844-49d2-9923-4a804c69fd06",a._sentryDebugIdIdentifier="sentry-dbid-c760babc-8844-49d2-9923-4a804c69fd06")}catch{}})();const $={class:"page"},E=x({__name:"Home",setup(a){const i=w(),{result:r,loading:b}=k(h),u=C(()=>{var o,l;return(l=(o=r.value)==null?void 0:o.sidebar.filter(d=>d.visible))!=null?l:[]}),v=o=>{i.push({path:`/${o}`})};return(o,l)=>{var d;return t(),m("div",$,[e(r)?(t(),s(F,{key:0,"runner-data":e(r),"hide-sidebar":""},null,8,["runner-data"])):_("",!0),I("div",{class:"container",style:D({backgroundColor:(d=e(r))==null?void 0:d.theme})},[e(b)?(t(),s(e(B),{key:0})):u.value.length===0?(t(),s(e(g),{key:1,type:"secondary",style:{"font-size":"18px"}},{default:n(()=>[f(" There are no public forms available ")]),_:1})):(t(),s(e(y),{key:2,vertical:"",gap:"large",style:{padding:"120px 0"}},{default:n(()=>[(t(!0),m(N,null,T(u.value,c=>(t(),s(e(S),{key:c.id,class:"form-card",onClick:L=>v(c.path)},{default:n(()=>[p(e(y),{gap:"large",align:"center",justify:"space-between"},{default:n(()=>[p(e(g),{style:{"font-size":"18px","font-weight":"500"}},{default:n(()=>[f(H(c.name),1)]),_:2},1024),p(V,{path:e(A),fill:"#000",width:"20"},null,8,["path"])]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1})),_("",!0)],4)])}}});const oe=z(E,[["__scopeId","data-v-5e8254cd"]]);export{oe as default};
//# sourceMappingURL=Home.8e172bf4.js.map
