import{B as f}from"./Base.a464e3b8.js";import{A as o}from"./Link.f80ea6a6.js";import{A as r}from"./Paragraph.fbd3cedb.js";import{A as a}from"./Text.4830f6bb.js";import{A as i}from"./Title.5b74a8b2.js";import{T as e}from"./Typography.9f15a3fb.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="9bc3379f-86d1-4ffd-8529-04f3e898b820",n._sentryDebugIdIdentifier="sentry-dbid-9bc3379f-86d1-4ffd-8529-04f3e898b820")}catch{}})();e.Text=a;e.Title=i;e.Paragraph=r;e.Link=o;e.Base=f;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,a),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.749b48cd.js.map
