import{d as f,eB as b,eA as C,H as g,b as _,c as I,u as h}from"./outputWidgets.02d7c6ab.js";import{b as w}from"./index.91e5c23a.js";import"./router.1ffd6f3d.js";import{C as i}from"./connector.9f55a1bd.js";import{a as k}from"./asyncComputed.6ba28f12.js";import{q as x,d as E}from"./icons.d148c279.js";import{C as D}from"./CrudView.9686d7bc.js";import"./index.cf4c23b9.js";import"./record.4bf6e864.js";import"./pubsub.ee609699.js";import"./FormItem.08e761e4.js";import"./hasIn.16bcfc34.js";import"./Paragraph.fbd3cedb.js";import"./Base.a464e3b8.js";import"./Typography.9f15a3fb.js";import"./Form.ad29b3fb.js";import"./Modal.04499883.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.754dc12b.js";import"./url.425ecd45.js";import"./index.3efceebc.js";import"./Title.5b74a8b2.js";import"./Text.4830f6bb.js";import"./index.48b86b74.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="9a8021a7-f5ca-42a5-91ad-668fcd6e9be6",o._sentryDebugIdIdentifier="sentry-dbid-9a8021a7-f5ca-42a5-91ad-668fcd6e9be6")}catch{}})();const W=f({__name:"Connectors",setup(o){const r=b(),a=C(),c=r.params.projectId;async function s(e){const t=await i.create(c,e.name,e.type);a.push({name:"connectorEditor",params:{connectorId:t.id}})}const p=[{key:"name",label:"Connector name",type:"text"},{key:"type",label:"Connector type",type:Object.entries(w.schema).map(([e,t])=>({value:e,label:t.label}))}],{loading:m,result:d,refetch:l}=k(()=>i.list(c)),u=g(()=>{var e,t;return{columns:[{name:"Name"},{name:"Type"},{name:"",align:"right"}],rows:(t=(e=d.value)==null?void 0:e.map(n=>({key:n.id,cells:[{type:"link",text:n.name,to:{name:"connectorEditor",params:{connectorId:n.id}}},{type:"text",text:n.type},{type:"actions",actions:[{icon:x,label:"Edit",onClick({key:y}){a.push({name:"connectorEditor",params:{connectorId:y}})}},{icon:E,label:"Delete",dangerous:!0,async onClick(){await n.delete(),l()}}]}]})))!=null?t:[]}});return(e,t)=>(_(),I(D,{"entity-name":"connector",loading:h(m),title:"Connectors",description:"Each connector is a version of your app. You can create a new connector by deploying your app from the local editor.","empty-title":"No connectors here yet",table:u.value,fields:p,"create-button-text":"Create connector",onCreate:s},null,8,["loading","table"]))}});export{W as default};
//# sourceMappingURL=Connectors.d15dc8dd.js.map
