import{ac as i,V as t,Q as r,f as p}from"./outputWidgets.02d7c6ab.js";import{B as c,b as l}from"./Base.a464e3b8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="5ab848c6-73b8-4152-8f24-696f0dc4a92f",e._sentryDebugIdIdentifier="sentry-dbid-5ab848c6-73b8-4152-8f24-696f0dc4a92f")}catch{}})();const b=()=>t(t({},r(l(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:a,attrs:d}=s;const{ellipsis:n}=e;i();const f=t(t(t({},e),{ellipsis:n&&typeof n=="object"?r(n,["expandable","rows"]):n,component:"span"}),d);return p(c,f,a)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=b();const g=o;export{g as A};
//# sourceMappingURL=Text.4830f6bb.js.map
