import{_ as u}from"./Navbar.vue_vue_type_script_setup_true_lang.7bd7c375.js";import{g as p}from"./api.2e2d3245.js";import{a as _}from"./asyncComputed.6ba28f12.js";import{W as b}from"./WidgetsFrame.ab064fcb.js";import{d as y,eB as g,b as n,ev as h,e as a,u as t,c as f,w as v,ex as d,eD as l,v as w}from"./outputWidgets.02d7c6ab.js";import"./index.4029c00a.js";import"./pubsub.ee609699.js";import"./Text.4830f6bb.js";import"./Base.a464e3b8.js";import"./Typography.9f15a3fb.js";import"./index.749b48cd.js";import"./Link.f80ea6a6.js";import"./Paragraph.fbd3cedb.js";import"./Title.5b74a8b2.js";import"./index.63b077a7.js";import"./runnerData.00697345.js";import"./url.425ecd45.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new D().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="e7fba50b-902d-4ff5-b2bb-b2765f85f338",o._sentryDebugIdIdentifier="sentry-dbid-e7fba50b-902d-4ff5-b2bb-b2765f85f338")}catch{}})();const k={class:"error"},I={class:"inner-content"},x=y({__name:"Error",setup(o){const r=g(),{result:e}=_(p),i=()=>{const{status:s}=r.params;switch(s){case"404":return{status:s,message:"Page not found."};case"403":return{status:s,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(s,B)=>(n(),h("div",null,[a("div",k,[t(e)?(n(),f(b,{key:0,"main-color":t(e).mainColor,theme:t(e).theme,"font-family":t(e).fontFamily,style:{height:"100vh"}},{default:v(()=>{var m,c;return[t(e)?(n(),f(u,{key:0,"brand-name":((m=t(e))==null?void 0:m.brandName)||((c=t(e))==null?void 0:c.name),"logo-url":t(e).logoUrl},null,8,["brand-name","logo-url"])):d("",!0),a("div",I,[a("h1",null,l(i().status),1),a("p",null,l(i().message),1)])]}),_:1},8,["main-color","theme","font-family"])):d("",!0)])]))}});const D=w(x,[["__scopeId","data-v-befb94cf"]]);export{D as default};
//# sourceMappingURL=Error.cb04c51e.js.map
