import{_ as s}from"./Navbar.vue_vue_type_script_setup_true_lang.7bd7c375.js";import{K as d,P as b,L as l}from"./repository.a7503037.js";import{d as c,b as u,ev as f,f as p,u as r}from"./outputWidgets.02d7c6ab.js";import{u as g}from"./index.4029c00a.js";import{a as y}from"./asyncComputed.6ba28f12.js";import{g as _}from"./api.2e2d3245.js";import"./Text.4830f6bb.js";import"./Base.a464e3b8.js";import"./Typography.9f15a3fb.js";import"./index.749b48cd.js";import"./Link.f80ea6a6.js";import"./Paragraph.fbd3cedb.js";import"./Title.5b74a8b2.js";import"./index.63b077a7.js";import"./ant-design.cc523265.js";import"./index.dfc44b72.js";import"./Modal.04499883.js";import"./api.7faaa5e8.js";import"./schema.34f5b08f.js";import"./index.cf4c23b9.js";import"./icons.d148c279.js";import"./index.3efceebc.js";import"./index.48b86b74.js";import"./index.07a02bf0.js";import"./index.08d9038c.js";import"./index.642f2887.js";import"./CollapsePanel.815fb916.js";import"./Form.ad29b3fb.js";import"./FormItem.08e761e4.js";import"./hasIn.16bcfc34.js";import"./Timeline.6177f759.js";import"./index.cfb5f9b9.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.42eac5ca.js";import"./scripts.49c5c535.js";import"./record.4bf6e864.js";import"./pubsub.ee609699.js";import"./workspaces.c829a0d7.js";import"./runnerData.00697345.js";import"./url.425ecd45.js";import"./ExpandOutlined.b1d30081.js";import"./Card.c07f4cec.js";import"./TabPane.ae8f30bc.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="6309a2c7-33c2-4bd3-ba5b-714db2d62967",o._sentryDebugIdIdentifier="sentry-dbid-6309a2c7-33c2-4bd3-ba5b-714db2d62967")}catch{}})();const bo=c({__name:"Kanban",setup(o){const t=new b(g),e=new l("kanban"),{result:a}=y(_);return(k,w)=>{var i,n,m;return u(),f("div",null,[p(s,{"brand-name":((i=r(a))==null?void 0:i.brandName)||((n=r(a))==null?void 0:n.name),"logo-url":(m=r(a))==null?void 0:m.logoUrl},null,8,["brand-name","logo-url"]),p(d,{"kanban-repository":r(t),storage:r(e)},null,8,["kanban-repository","storage"])])}}});export{bo as default};
//# sourceMappingURL=Kanban.2bf41980.js.map
