import{v as t,b as s,ev as o}from"./outputWidgets.02d7c6ab.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="4f907f33-1478-4182-bbbc-154773f27268",e._sentryDebugIdIdentifier="sentry-dbid-4f907f33-1478-4182-bbbc-154773f27268")}catch{}})();const r={},i={class:"organization-settings"};function f(e,n){return s(),o("div",i,"Organization settings")}const d=t(r,[["render",f]]);export{d as default};
//# sourceMappingURL=OrganizationSettings.d7b73e9f.js.map
