.terminal[data-v-032cbeba]{margin-top:20px;width:96%;background-color:#212427;padding:12px 16px;border-radius:8px;overflow:scroll}.log-text[data-v-032cbeba]{color:#fff;margin:4px}.panel[data-v-3683921a] .ant-collapse-header{padding:0}.stages-container[data-v-0cd7f22b]{max-width:100vw;position:relative;flex-grow:1}.stages-container .stages-content[data-v-0cd7f22b]{padding:20px;overflow:auto}
