import"./outputWidgets.02d7c6ab.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="58925656-cc62-4846-b1c6-6d9069146c06",e._sentryDebugIdIdentifier="sentry-dbid-58925656-cc62-4846-b1c6-6d9069146c06")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.425ecd45.js.map
