import{cz as r}from"./outputWidgets.02d7c6ab.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="f3fde8d9-b737-4222-b301-d490333e14f6",e._sentryDebugIdIdentifier="sentry-dbid-f3fde8d9-b737-4222-b301-d490333e14f6")}catch{}})();const o=(e,d)=>{r.error({message:e,description:d})};export{o as p};
//# sourceMappingURL=popupNotifcation.c6a54eda.js.map
