import{g as i}from"./api.2e2d3245.js";import{P as m}from"./Passwordless.e2ab0c2b.js";import{a as f}from"./asyncComputed.6ba28f12.js";import{W as p}from"./WidgetsFrame.ab064fcb.js";import{d as u,eA as l,eB as _,b as c,ev as y,e as g,u as s,c as b,w as h,ex as w,f as v,v as k}from"./outputWidgets.02d7c6ab.js";import"./runnerData.00697345.js";import"./url.425ecd45.js";import"./index.4029c00a.js";import"./pubsub.ee609699.js";import"./icons.d148c279.js";import"./CircularLoading.b61b1cd3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="662c8e06-0125-4fec-8f2e-cb898ee65b5d",e._sentryDebugIdIdentifier="sentry-dbid-662c8e06-0125-4fec-8f2e-cb898ee65b5d")}catch{}})();const x={class:"login"},I=u({__name:"Login",setup(e){const t=l(),r=_(),{result:o}=f(i),d=()=>{const{redirect:a,...n}=r.query;if(a){t.push({path:a,query:n,params:r.params});return}t.push({name:"playerKanban",query:n})};return(a,n)=>(c(),y("div",null,[g("div",x,[s(o)?(c(),b(p,{key:0,"main-color":s(o).mainColor,theme:s(o).theme,"font-family":s(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(m,{onDone:d})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const R=k(I,[["__scopeId","data-v-33714d9d"]]);export{R as default};
//# sourceMappingURL=Login.9bc66de9.js.map
