import{N as b}from"./NavbarControls.37ab9545.js";import{d as l,eA as _,eB as y,H as g,a as v,b as c,ev as h,f as e,w as s,u as r,e as k,a$ as w,ar as S,c as x,eS as q,v as A}from"./outputWidgets.02d7c6ab.js";import{A as B}from"./Text.4830f6bb.js";import{T as C,A as o}from"./TabPane.ae8f30bc.js";import{c as I}from"./index.63b077a7.js";import"./index.4029c00a.js";import"./pubsub.ee609699.js";import"./asyncComputed.6ba28f12.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.9896c425.js";import"./ant-design.cc523265.js";import"./index.dfc44b72.js";import"./Modal.04499883.js";import"./Typography.9f15a3fb.js";import"./Link.f80ea6a6.js";import"./Base.a464e3b8.js";import"./index.4ba74983.js";import"./workspaces.c829a0d7.js";import"./runnerData.00697345.js";import"./url.425ecd45.js";import"./record.4bf6e864.js";import"./popupNotifcation.c6a54eda.js";import"./icons.d148c279.js";import"./index.3efceebc.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.754dc12b.js";import"./Paragraph.fbd3cedb.js";import"./hasIn.16bcfc34.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="35314147-c1f2-4f91-b95d-fdfb1e39b847",a._sentryDebugIdIdentifier="sentry-dbid-35314147-c1f2-4f91-b95d-fdfb1e39b847")}catch{}})();const T={class:"content"},D=l({__name:"Settings",setup(a){const t=_(),n=y();function m(){t.push({name:"home"})}const u=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function p(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return c(),h(w,null,[e(r(I),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(b,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(r(B),null,{default:s(()=>[S("Settings")]),_:1})]),footer:s(()=>[e(r(C),{"active-key":u.value,onChange:p},{default:s(()=>[e(r(o),{key:"style",tab:"Style"}),e(r(o),{key:"sidebar",tab:"Sidebar"}),e(r(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",T,[e(d,null,{default:s(({Component:f})=>[(c(),x(q(f)))]),_:1})])],64)}}});const oe=A(D,[["__scopeId","data-v-772f4b10"]]);export{oe as default};
//# sourceMappingURL=Settings.a675dfc0.js.map
