import{eW as n,eX as t}from"./outputWidgets.02d7c6ab.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="99b3c44c-f168-44d3-b712-94b848bdded8",e._sentryDebugIdIdentifier="sentry-dbid-99b3c44c-f168-44d3-b712-94b848bdded8")}catch{}})();function s(e,d){return n(1,arguments),t(e,Date.now(),d)}export{s as f};
//# sourceMappingURL=index.07a02bf0.js.map
