import{C as t,A as m}from"./CollapsePanel.815fb916.js";import{F as n}from"./Form.ad29b3fb.js";import{aM as i,co as r}from"./outputWidgets.02d7c6ab.js";import{T as o,A as a}from"./Timeline.6177f759.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="009d568c-9eab-43d5-a3f0-9be843e9faac",e._sentryDebugIdIdentifier="sentry-dbid-009d568c-9eab-43d5-a3f0-9be843e9faac")}catch{}})();t.Panel=m;t.install=function(e){return e.component(t.name,t),e.component(m.name,m),e};n.useInjectFormItemContext=i;n.ItemRest=r;n.install=function(e){return e.component(n.name,n),e.component(n.Item.name,n.Item),e.component(r.name,r),e};o.Item=a;o.install=function(e){return e.component(o.name,o),e.component(a.name,a),e};
//# sourceMappingURL=index.642f2887.js.map
