import{K as n,E as p,L as s}from"./repository.a7503037.js";import{d as a,b as m,c,u as e}from"./outputWidgets.02d7c6ab.js";import{l as d}from"./index.4029c00a.js";import"./ant-design.cc523265.js";import"./index.dfc44b72.js";import"./Modal.04499883.js";import"./asyncComputed.6ba28f12.js";import"./api.7faaa5e8.js";import"./schema.34f5b08f.js";import"./index.cf4c23b9.js";import"./icons.d148c279.js";import"./index.3efceebc.js";import"./index.48b86b74.js";import"./index.07a02bf0.js";import"./Paragraph.fbd3cedb.js";import"./Base.a464e3b8.js";import"./Typography.9f15a3fb.js";import"./index.749b48cd.js";import"./Link.f80ea6a6.js";import"./Text.4830f6bb.js";import"./Title.5b74a8b2.js";import"./index.08d9038c.js";import"./index.642f2887.js";import"./CollapsePanel.815fb916.js";import"./Form.ad29b3fb.js";import"./FormItem.08e761e4.js";import"./hasIn.16bcfc34.js";import"./Timeline.6177f759.js";import"./index.cfb5f9b9.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.42eac5ca.js";import"./scripts.49c5c535.js";import"./record.4bf6e864.js";import"./pubsub.ee609699.js";import"./workspaces.c829a0d7.js";import"./runnerData.00697345.js";import"./url.425ecd45.js";import"./ExpandOutlined.b1d30081.js";import"./Card.c07f4cec.js";import"./TabPane.ae8f30bc.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="45ce4f11-90ce-46fd-a120-db628e985347",t._sentryDebugIdIdentifier="sentry-dbid-45ce4f11-90ce-46fd-a120-db628e985347")}catch{}})();class f{constructor(o=d){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const to=a({__name:"WorkflowKanban",setup(t){const o=new p,r=new f,i=new s("kanban");return(u,y)=>(m(),c(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{to as default};
//# sourceMappingURL=WorkflowKanban.31654c73.js.map
