import{d as m,eB as f,u as e,b as d,c as u,ev as y,f as a,w as o,bv as _,ar as p,ex as g,e as b,eD as x}from"./outputWidgets.02d7c6ab.js";import"./router.1ffd6f3d.js";import"./index.91e5c23a.js";import{O as w}from"./organization.6d3db9f6.js";import{a as k}from"./asyncComputed.6ba28f12.js";import{A}from"./Title.5b74a8b2.js";import{A as B}from"./index.3efceebc.js";import{A as h}from"./index.503c34f2.js";import{A as C}from"./Text.4830f6bb.js";import{C as v}from"./Card.c07f4cec.js";import"./FormItem.08e761e4.js";import"./hasIn.16bcfc34.js";import"./index.cf4c23b9.js";import"./record.4bf6e864.js";import"./pubsub.ee609699.js";import"./Base.a464e3b8.js";import"./Typography.9f15a3fb.js";import"./TabPane.ae8f30bc.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="5972c725-caa7-4e15-8567-a0b18493d4b4",t._sentryDebugIdIdentifier="sentry-dbid-5972c725-caa7-4e15-8567-a0b18493d4b4")}catch{}})();const D={key:1},I={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},W=m({__name:"Billing",setup(t){const n=f().params.organizationId,{loading:l,result:c}=k(()=>w.get(n));return(z,N)=>e(l)?(d(),u(e(_),{key:0})):(d(),y("div",D,[a(e(B),{justify:"space-between",align:"center"},{default:o(()=>[a(e(A),{level:3},{default:o(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),a(e(h),{style:{"margin-top":"0"}}),a(e(v),{style:{width:"300px"}},{default:o(()=>{var i,s;return[a(e(C),{type:"secondary"},{default:o(()=>[p("Plan")]),_:1}),b("div",I,x((s=(i=e(c))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{W as default};
//# sourceMappingURL=Billing.d6497667.js.map
