import{V as s,f as p,Q as f}from"./outputWidgets.02d7c6ab.js";import{B as d,b}from"./Base.a464e3b8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="9f976fb3-6e41-47f8-9af9-b26b36d94b8b",e._sentryDebugIdIdentifier="sentry-dbid-9f976fb3-6e41-47f8-9af9-b26b36d94b8b")}catch{}})();const i=()=>f(b(),["component"]),a=(e,r)=>{let{slots:t,attrs:o}=r;const n=s(s(s({},e),{component:"div"}),o);return p(d,n,t)};a.displayName="ATypographyParagraph";a.inheritAttrs=!1;a.props=i();const c=a;export{c as A};
//# sourceMappingURL=Paragraph.fbd3cedb.js.map
