import{s as a}from"./schema.34f5b08f.js";import"./outputWidgets.02d7c6ab.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="b1347ed9-8afc-47f6-a7c1-fcfdd57a2435",t._sentryDebugIdIdentifier="sentry-dbid-b1347ed9-8afc-47f6-a7c1-fcfdd57a2435")}catch{}})();const s={"Content-Type":"application/json"},i="abstra-run-id";class f{async load(){const e=await fetch("/_editor/api/workflows");if(e.ok){const o=await e.json();return a.parse(o)}else throw new Error("Failed to fetch initial data")}async update(e){const o=await fetch("/_editor/api/workflows",{method:"PUT",headers:s,body:JSON.stringify(e)});if(o.ok){const n=await o.json();return a.parse(n)}else throw new Error("Failed to update workflow")}}export{i as A,f as W};
//# sourceMappingURL=api.7faaa5e8.js.map
